@@ -19,6 +19,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -30,7 +31,18 @@
 #include "fr-command-arj.h"
 
 
-G_DEFINE_TYPE (FrCommandArj, fr_command_arj, FR_TYPE_COMMAND)
+struct _FrCommandArj
+{
+	FrCommand parent_instance;
+
+	gboolean  list_started;
+	int       line_no;
+	FileData *fdata;
+	GRegex   *filename_line_regex;
+};
+
+
+G_DEFINE_TYPE (FrCommandArj, fr_command_arj, fr_command_get_type ())
 
 
 /* -- list -- */
