@@ -19,7 +19,13 @@
 #include "fr-command-lrzip.h"
 
 
-G_DEFINE_TYPE (FrCommandLrzip, fr_command_lrzip, FR_TYPE_COMMAND)
+struct _FrCommandLrzip
+{
+	FrCommand  parent_instance;
+};
+
+
+G_DEFINE_TYPE (FrCommandLrzip, fr_command_lrzip, fr_command_get_type ())
 
 
 /* -- list -- */
@@ -45,7 +51,11 @@ list__process_line (char     *line,
 
 	struct stat st;
 	if (stat (comm->filename, &st) == 0)
+#ifdef __APPLE__
+		fdata->modified = st.st_mtime;
+#else
 		fdata->modified = st.st_mtim.tv_sec;
+#endif
 	else
 		time(&(fdata->modified));
 
